@@ -8,14 +8,13 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( get_download_info );
 
-use JSON             qw( decode_json );
-use Term::ANSIScreen qw( :screen );
+use JSON qw( decode_json );
 
-use App::YTDL::Helper qw( uni_capture HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::Helper qw( uni_capture );
 
 
 sub get_download_info {
-    my ( $set, $opt, $webpage_url, $message, $flat ) = @_;
+    my ( $set, $opt, $webpage_url, $flat ) = @_;
     my @cmd = @{$set->{youtube_dl}};
     push @cmd, '--youtube-skip-dash-manifest';
     push @cmd, '--dump-single-json';
@@ -27,23 +26,19 @@ sub get_download_info {
     RETRY: while ( 1 ) {
         $count++;
         if ( eval {
-            print HIDE_CURSOR;
-            print $message;
             $json_all = uni_capture( @cmd );
-            print "\r", clline;
-            print SHOW_CURSOR;
-            die $webpage_url . ' - no JSON!' if ! $json_all;
+            die 'no JSON!' if ! $json_all;
             1 }
         ) {
             last RETRY;
         }
         else {
-            print SHOW_CURSOR;
             if ( $count > $opt->{retries} ) {
-                push @{$set->{error_get_download_infos}}, $webpage_url;
-                return;
+                die "Error download info: $webpage_url!";
             }
-            say "$count/$opt->{retries}  $webpage_url: $@";
+            my $error = $@;
+            chomp $error;
+            print "  $count/$opt->{retries}  $webpage_url: $error\n";
             sleep $opt->{retries} * 3;
         }
     }
